@@ -319,13 +319,15 @@ def get_filename(prompt, title=None, force_prompt=False, default=''):
 
 
 def select_multiple(par, options, prompt, default=None, title=None,
-                    order=None, extras=None):
+                    order=None, extras=None, enable_other={}):
     return menu(par, options, prompt, default=default, title=title,
-                order=order, extras=extras, multiple=True, empty_ok=False)
+                order=order, extras=extras, multiple=True, empty_ok=False,
+                enable_other=enable_other)
 
 
 def menu(par, options, prompt, default=None, title=None, any_ok=False,
-         order=None, extras=None, multiple=False, empty_ok=False):
+         order=None, extras=None, multiple=False, empty_ok=False,
+         enable_other={}):
     if multiple:
         if default is None:
             default = []
@@ -424,6 +426,9 @@ def menu(par, options, prompt, default=None, title=None, any_ok=False,
                     del selected[response]
                 else:
                     selected[response] = 1
+                    other = enable_other.get(response)
+                    if other:
+                        selected[other] = 1
                 ewrite('- selected: %s\n' % ', '.join(list(selected.keys())))
                 if len(selected):
                     default = 'done'
