@@ -11,30 +11,30 @@ import debianbts
 class TestBugreport(unittest.TestCase):
     # TODO: differentiate for all possible cases? f.e. sysinfo True/False and then change if 'System Information' in self.text?
 
-    def test_bugreport(self):
+    def test_bugreport(self) -> None:
         self.body = 'test'
         self.package = 'reportbug'
         self.report = bugreport(package=self.package, body=self.body)
-        self.text = self.report.__unicode__()
+        self.text = self.report.__str__()
 
         self.assertIn(self.body, self.text)
         self.assertIn(self.package, self.text)
 
     # verify that for special packages, we don't add the report template
-    def test_bts643785(self):
+    def test_bts643785(self) -> None:
         for package in list(debbugs.SYSTEMS['debian'].get('specials', {}).keys()):
-            self.report = bugreport(package=package, mode=utils.MODE_NOVICE)
-            self.text = self.report.__unicode__()
+            self.report = bugreport(package=package, mode=utils.MODE.NOVICE)
+            self.text = self.report.__str__()
             self.assertNotIn(utils.NEWBIELINE, self.text)
 
     @pytest.mark.network  # marking the test as using network
-    def test_followup(self):
+    def test_followup(self) -> None:
         self.body = 'test'
         self.package = 'reportbug'
         self.tags = 'patch ftbfs'
         self.report = bugreport(package=self.package, body=self.body,
                                 followup=123456, tags=self.tags)
-        self.text = self.report.__unicode__()
+        self.text = self.report.__str__()
 
         self.assertIn('Followup-For: Bug #123456', self.text)
         self.assertIn(f'Control: tags -1 {self.tags}', self.text)
@@ -44,7 +44,7 @@ class TestBugreport(unittest.TestCase):
         bug = debianbts.get_status([123456])[0]
         self.report = bugreport(package=self.package, body=self.body,
                                 followup=bug)
-        self.text = self.report.__unicode__()
+        self.text = self.report.__str__()
 
         self.assertIn('Followup-For: Bug #123456', self.text)
         self.assertNotIn('Control: tags -1 ', self.text)
