@@ -34,19 +34,34 @@ class MockUI:
 
 
 class TestSpecials(unittest.TestCase):
-    def test_handle_debian_ftp(self):
+    def test_handle_debian_ftp(self) -> None:
         with self.assertRaises(SystemExit):
             debbugs.handle_debian_ftp('reportbug', '', MockUI(None), None, 60)
         self.assertIsNone(debbugs.handle_debian_ftp('reportbug', '', MockUI('other'), None, 60))
         self.assertEqual(
             debbugs.handle_debian_ftp('reportbug', '', MockUI('RoQA', 'reportbug', None, 'is broken', 'n'), None, 60),
-            ('RM: reportbug -- RoQA; is broken', 'normal', [], [], '', False)
+            (
+                'RM: reportbug -- RoQA; is broken', 'normal', [],
+                [
+                    'Control: affects -1 + src:reportbug',
+                    'X-Debbugs-Cc: reportbug@packages.debian.org',
+                    'User: ftp.debian.org@packages.debian.org',
+                    'Usertags: remove'
+                ],
+                '', False
+            )
         )
         self.assertEqual(
             debbugs.handle_debian_ftp('reportbug', '', MockUI('override', 'reportbug', 'utils', 'important', None), None, 60),
             (
                 'override: reportbug:utils/important', 'normal', [],
-                ['User: ftp.debian.org@packages.debian.org', 'Usertags: override', 'X-Debbugs-Cc: debian-boot@lists.debian.org'],
+                [
+                    'Control: affects -1 + src:reportbug',
+                    'X-Debbugs-Cc: reportbug@packages.debian.org',
+                    'User: ftp.debian.org@packages.debian.org',
+                    'Usertags: override',
+                    'X-Debbugs-Cc: debian-boot@lists.debian.org',
+                ],
                 '(Describe here the reason for this change)', False
             )
         )
@@ -66,13 +81,18 @@ class TestSpecials(unittest.TestCase):
         self.assertTrue(ret[0].startswith('nmu: reportbug_'))
         self.assertEqual(ret[1], 'normal')
         self.assertEqual(ret[2], [])
-        self.assertEqual(ret[3], ['User: release.debian.org@packages.debian.org', 'Usertags: binnmu'])
+        self.assertEqual(ret[3], [
+            'Control: affects -1 + src:reportbug',
+            'X-Debbugs-Cc: reportbug@packages.debian.org',
+            'User: release.debian.org@packages.debian.org',
+            'Usertags: binnmu'
+        ])
         self.assertTrue(ret[4].startswith('nmu reportbug_'))
         self.assertIn('unstable', ret[4])
         self.assertTrue(ret[4].endswith('"no change"\n'))
         self.assertFalse(ret[5])
 
-    def test_handle_debian_release_britney(self):
+    def test_handle_debian_release_britney(self) -> None:
         ret = debbugs.handle_debian_release(
             'reportbug', '',
             MockUI('britney', 'mysubject'),
@@ -85,7 +105,7 @@ class TestSpecials(unittest.TestCase):
         self.assertEqual(ret[4], '')
         self.assertTrue(ret[5])
 
-    def test_handle_debian_release_transition(self):
+    def test_handle_debian_release_transition(self) -> None:
         ret = debbugs.handle_debian_release(
             'reportbug', '',
             MockUI('transition', 'reportbug', 'oldname', 'newname'),
@@ -94,13 +114,18 @@ class TestSpecials(unittest.TestCase):
         self.assertEqual(ret[0], 'transition: reportbug')
         self.assertEqual(ret[1], 'normal')
         self.assertEqual(ret[2], [])
-        self.assertEqual(ret[3], ['User: release.debian.org@packages.debian.org', 'Usertags: transition'])
+        self.assertEqual(ret[3], [
+            'Control: affects -1 + src:reportbug',
+            'X-Debbugs-Cc: reportbug@packages.debian.org',
+            'User: release.debian.org@packages.debian.org',
+            'Usertags: transition'
+        ])
         self.assertTrue(ret[4].startswith('(please explain'))
         self.assertIn('Ben file:', ret[4])
         self.assertTrue(ret[4].endswith('"oldname";\n\n'))
         self.assertFalse(ret[5])
 
-    def test_handle_debian_release_unblock(self):
+    def test_handle_debian_release_unblock(self) -> None:
         ret = debbugs.handle_debian_release(
             'reportbug', '',
             MockUI('unblock', 'reportbug', 'y'),
@@ -109,11 +134,16 @@ class TestSpecials(unittest.TestCase):
         self.assertTrue(ret[0].startswith('unblock: reportbug/'))
         self.assertEqual(ret[1], 'normal')
         self.assertEqual(ret[2], [])
-        self.assertEqual(ret[3], ['User: release.debian.org@packages.debian.org', 'Usertags: unblock'])
+        self.assertEqual(ret[3], [
+            'Control: affects -1 + src:reportbug',
+            'X-Debbugs-Cc: reportbug@packages.debian.org',
+            'User: release.debian.org@packages.debian.org',
+            'Usertags: unblock'
+        ])
         self.assertTrue(ret[4].startswith('Please unblock package reportbug\n\n'))
         self.assertFalse(ret[5])
 
-    def test_handle_debian_release_rm(self):
+    def test_handle_debian_release_rm(self) -> None:
         ret = debbugs.handle_debian_release(
             'reportbug', '',
             MockUI('rm', 'reportbug', 'y', 'n', 'y'),
@@ -122,7 +152,12 @@ class TestSpecials(unittest.TestCase):
         self.assertTrue(ret[0].startswith('RM: reportbug/'))
         self.assertEqual(ret[1], 'normal')
         self.assertEqual(ret[2], [])
-        self.assertEqual(ret[3], ['User: release.debian.org@packages.debian.org', 'Usertags: rm'])
+        self.assertEqual(ret[3], [
+            'Control: affects -1 + src:reportbug',
+            'X-Debbugs-Cc: reportbug@packages.debian.org',
+            'User: release.debian.org@packages.debian.org',
+            'Usertags: rm'
+        ])
         self.assertEqual(ret[4], '(explain the reason for the removal here)\n')
         self.assertFalse(ret[5])
         with self.assertRaises(SystemExit):
@@ -132,7 +167,7 @@ class TestSpecials(unittest.TestCase):
                 None, 60
             )
 
-    def test_handle_debian_release_pu(self):
+    def test_handle_debian_release_pu(self) -> None:
         ret = debbugs.handle_debian_release(
             'reportbug', '',
             MockUI('oldstable-pu', 'reportbug'),
@@ -141,11 +176,17 @@ class TestSpecials(unittest.TestCase):
         self.assertTrue(ret[0].startswith('oldstable-pu: package reportbug/'))
         self.assertEqual(ret[1], 'normal')
         self.assertEqual(ret[2], [])
-        self.assertEqual(ret[3], ['User: release.debian.org@packages.debian.org', 'Usertags: pu', 'Tags: oldstable'])
+        self.assertEqual(ret[3], [
+            'Control: affects -1 + src:reportbug',
+            'X-Debbugs-Cc: reportbug@packages.debian.org',
+            'User: release.debian.org@packages.debian.org',
+            'Usertags: pu',
+            'Tags: oldstable'
+        ])
         self.assertTrue(ret[4].startswith('(Please provide enough information'))
         self.assertFalse(ret[5])
 
-    def test_handle_wnpp(self):
+    def test_handle_wnpp(self) -> None:
         with self.assertRaises(SystemExit):
             debbugs.handle_wnpp('reportbug', '', MockUI(None), None, 60)
 
@@ -157,7 +198,10 @@ class TestSpecials(unittest.TestCase):
         self.assertTrue(ret[0].startswith('RFA: reportbug'))
         self.assertEqual(ret[1], 'normal')
         self.assertEqual(ret[2], [])
-        self.assertEqual(ret[3], ['Control: affects -1 src:reportbug'])
+        self.assertEqual(ret[3], [
+            'Control: affects -1 + src:reportbug',
+            'X-Debbugs-Cc: reportbug@packages.debian.org'
+        ])
         self.assertTrue(ret[4].startswith('I request an adopter'))
         self.assertFalse(ret[5])
 
@@ -186,7 +230,7 @@ class TestSpecials(unittest.TestCase):
         self.assertTrue(ret[4].startswith('(Please provide'))
         self.assertTrue(ret[5])
 
-    def test_handle_upgrade_report(self):
+    def test_handle_upgrade_report(self) -> None:
         ret = debbugs.handle_upgrade_report('reportbug', '', MockUI(), None, 60)
         self.assertEqual(ret[0], "")
         self.assertEqual(ret[1], "")
@@ -197,83 +241,83 @@ class TestSpecials(unittest.TestCase):
 
 
 class TestDebianbts(unittest.TestCase):
-    def test_get_tags(self):
+    def test_get_tags(self) -> None:
         # for each severity, for each mode
-        self.assertCountEqual(list(debbugs.get_tags('critical', utils.MODE_NOVICE).keys()),
+        self.assertCountEqual(list(debbugs.get_tags('critical', utils.MODE.NOVICE).keys()),
                               ['a11y', 'lfs', 'l10n', 'd-i', 'upstream', 'ipv6', 'security', 'patch', 'ftbfs'])
-        self.assertCountEqual(list(debbugs.get_tags('grave', utils.MODE_NOVICE).keys()),
+        self.assertCountEqual(list(debbugs.get_tags('grave', utils.MODE.NOVICE).keys()),
                               ['a11y', 'lfs', 'l10n', 'd-i', 'upstream', 'ipv6', 'security', 'patch', 'ftbfs'])
-        self.assertCountEqual(list(debbugs.get_tags('serious', utils.MODE_NOVICE).keys()),
+        self.assertCountEqual(list(debbugs.get_tags('serious', utils.MODE.NOVICE).keys()),
                               ['a11y', 'lfs', 'l10n', 'd-i', 'upstream', 'ipv6', 'security', 'patch', 'ftbfs'])
-        self.assertCountEqual(list(debbugs.get_tags('important', utils.MODE_NOVICE).keys()),
+        self.assertCountEqual(list(debbugs.get_tags('important', utils.MODE.NOVICE).keys()),
                               ['a11y', 'lfs', 'l10n', 'd-i', 'upstream', 'ipv6', 'patch', 'ftbfs'])
-        self.assertCountEqual(list(debbugs.get_tags('does-not-build', utils.MODE_NOVICE).keys()),
+        self.assertCountEqual(list(debbugs.get_tags('does-not-build', utils.MODE.NOVICE).keys()),
                               ['a11y', 'lfs', 'l10n', 'd-i', 'upstream', 'ipv6', 'patch', 'ftbfs'])
-        self.assertCountEqual(list(debbugs.get_tags('normal', utils.MODE_NOVICE).keys()),
+        self.assertCountEqual(list(debbugs.get_tags('normal', utils.MODE.NOVICE).keys()),
                               ['a11y', 'lfs', 'l10n', 'd-i', 'upstream', 'ipv6', 'patch', 'ftbfs'])
-        self.assertCountEqual(list(debbugs.get_tags('non-critical', utils.MODE_NOVICE).keys()),
+        self.assertCountEqual(list(debbugs.get_tags('non-critical', utils.MODE.NOVICE).keys()),
                               ['a11y', 'lfs', 'l10n', 'd-i', 'upstream', 'ipv6', 'patch', 'ftbfs'])
-        self.assertCountEqual(list(debbugs.get_tags('minor', utils.MODE_NOVICE).keys()),
+        self.assertCountEqual(list(debbugs.get_tags('minor', utils.MODE.NOVICE).keys()),
                               ['a11y', 'lfs', 'l10n', 'd-i', 'upstream', 'ipv6', 'patch', 'ftbfs'])
-        self.assertCountEqual(list(debbugs.get_tags('wishlist', utils.MODE_NOVICE).keys()),
+        self.assertCountEqual(list(debbugs.get_tags('wishlist', utils.MODE.NOVICE).keys()),
                               ['a11y', 'lfs', 'l10n', 'd-i', 'upstream', 'ipv6', 'patch', 'ftbfs'])
 
-        self.assertCountEqual(list(debbugs.get_tags('critical', utils.MODE_STANDARD).keys()),
-                              ['a11y', 'lfs', 'l10n', 'd-i', 'upstream', 'ipv6', 'security', 'patch', 'newcomer', 'ftbfs'])
-        self.assertCountEqual(list(debbugs.get_tags('grave', utils.MODE_STANDARD).keys()),
-                              ['a11y', 'lfs', 'l10n', 'd-i', 'upstream', 'ipv6', 'security', 'patch', 'newcomer', 'ftbfs'])
-        self.assertCountEqual(list(debbugs.get_tags('serious', utils.MODE_STANDARD).keys()),
-                              ['a11y', 'lfs', 'l10n', 'd-i', 'upstream', 'ipv6', 'security', 'patch', 'newcomer', 'ftbfs'])
-        self.assertCountEqual(list(debbugs.get_tags('important', utils.MODE_STANDARD).keys()),
-                              ['a11y', 'lfs', 'l10n', 'd-i', 'upstream', 'ipv6', 'patch', 'newcomer', 'ftbfs'])
-        self.assertCountEqual(list(debbugs.get_tags('does-not-build', utils.MODE_STANDARD).keys()),
-                              ['a11y', 'lfs', 'l10n', 'd-i', 'upstream', 'ipv6', 'patch', 'newcomer', 'ftbfs'])
-        self.assertCountEqual(list(debbugs.get_tags('normal', utils.MODE_STANDARD).keys()),
-                              ['a11y', 'lfs', 'l10n', 'd-i', 'upstream', 'ipv6', 'patch', 'newcomer', 'ftbfs'])
-        self.assertCountEqual(list(debbugs.get_tags('non-critical', utils.MODE_STANDARD).keys()),
-                              ['a11y', 'lfs', 'l10n', 'd-i', 'upstream', 'ipv6', 'patch', 'newcomer', 'ftbfs'])
-        self.assertCountEqual(list(debbugs.get_tags('minor', utils.MODE_STANDARD).keys()),
-                              ['a11y', 'lfs', 'l10n', 'd-i', 'upstream', 'ipv6', 'patch', 'newcomer', 'ftbfs'])
-        self.assertCountEqual(list(debbugs.get_tags('wishlist', utils.MODE_STANDARD).keys()),
-                              ['a11y', 'lfs', 'l10n', 'd-i', 'upstream', 'ipv6', 'patch', 'newcomer', 'ftbfs'])
+        self.assertCountEqual(list(debbugs.get_tags('critical', utils.MODE.STANDARD).keys()),
+                              ['a11y', 'lfs', 'l10n', 'd-i', 'upstream', 'ipv6', 'security', 'patch', 'newcomer', 'ftbfs', 'arch'])
+        self.assertCountEqual(list(debbugs.get_tags('grave', utils.MODE.STANDARD).keys()),
+                              ['a11y', 'lfs', 'l10n', 'd-i', 'upstream', 'ipv6', 'security', 'patch', 'newcomer', 'ftbfs', 'arch'])
+        self.assertCountEqual(list(debbugs.get_tags('serious', utils.MODE.STANDARD).keys()),
+                              ['a11y', 'lfs', 'l10n', 'd-i', 'upstream', 'ipv6', 'security', 'patch', 'newcomer', 'ftbfs', 'arch'])
+        self.assertCountEqual(list(debbugs.get_tags('important', utils.MODE.STANDARD).keys()),
+                              ['a11y', 'lfs', 'l10n', 'd-i', 'upstream', 'ipv6', 'patch', 'newcomer', 'ftbfs', 'arch'])
+        self.assertCountEqual(list(debbugs.get_tags('does-not-build', utils.MODE.STANDARD).keys()),
+                              ['a11y', 'lfs', 'l10n', 'd-i', 'upstream', 'ipv6', 'patch', 'newcomer', 'ftbfs', 'arch'])
+        self.assertCountEqual(list(debbugs.get_tags('normal', utils.MODE.STANDARD).keys()),
+                              ['a11y', 'lfs', 'l10n', 'd-i', 'upstream', 'ipv6', 'patch', 'newcomer', 'ftbfs', 'arch'])
+        self.assertCountEqual(list(debbugs.get_tags('non-critical', utils.MODE.STANDARD).keys()),
+                              ['a11y', 'lfs', 'l10n', 'd-i', 'upstream', 'ipv6', 'patch', 'newcomer', 'ftbfs', 'arch'])
+        self.assertCountEqual(list(debbugs.get_tags('minor', utils.MODE.STANDARD).keys()),
+                              ['a11y', 'lfs', 'l10n', 'd-i', 'upstream', 'ipv6', 'patch', 'newcomer', 'ftbfs', 'arch'])
+        self.assertCountEqual(list(debbugs.get_tags('wishlist', utils.MODE.STANDARD).keys()),
+                              ['a11y', 'lfs', 'l10n', 'd-i', 'upstream', 'ipv6', 'patch', 'newcomer', 'ftbfs', 'arch'])
 
-        self.assertCountEqual(list(debbugs.get_tags('critical', utils.MODE_ADVANCED).keys()),
-                              ['a11y', 'l10n', 'd-i', 'ipv6', 'patch', 'lfs', 'upstream', 'security', 'newcomer', 'ftbfs'])
-        self.assertCountEqual(list(debbugs.get_tags('grave', utils.MODE_ADVANCED).keys()),
-                              ['a11y', 'l10n', 'd-i', 'ipv6', 'patch', 'lfs', 'upstream', 'security', 'newcomer', 'ftbfs'])
-        self.assertCountEqual(list(debbugs.get_tags('serious', utils.MODE_ADVANCED).keys()),
-                              ['a11y', 'l10n', 'd-i', 'ipv6', 'patch', 'lfs', 'upstream', 'security', 'newcomer', 'ftbfs'])
-        self.assertCountEqual(list(debbugs.get_tags('important', utils.MODE_ADVANCED).keys()),
-                              ['a11y', 'l10n', 'd-i', 'ipv6', 'patch', 'lfs', 'upstream', 'security', 'newcomer', 'ftbfs'])
-        self.assertCountEqual(list(debbugs.get_tags('does-not-build', utils.MODE_ADVANCED).keys()),
-                              ['a11y', 'l10n', 'd-i', 'ipv6', 'patch', 'lfs', 'upstream', 'security', 'newcomer', 'ftbfs'])
-        self.assertCountEqual(list(debbugs.get_tags('normal', utils.MODE_ADVANCED).keys()),
-                              ['a11y', 'l10n', 'd-i', 'ipv6', 'patch', 'lfs', 'upstream', 'security', 'newcomer', 'ftbfs'])
-        self.assertCountEqual(list(debbugs.get_tags('non-critical', utils.MODE_ADVANCED).keys()),
-                              ['a11y', 'l10n', 'd-i', 'ipv6', 'patch', 'lfs', 'upstream', 'security', 'newcomer', 'ftbfs'])
-        self.assertCountEqual(list(debbugs.get_tags('minor', utils.MODE_ADVANCED).keys()),
-                              ['a11y', 'l10n', 'd-i', 'ipv6', 'patch', 'lfs', 'upstream', 'security', 'newcomer', 'ftbfs'])
-        self.assertCountEqual(list(debbugs.get_tags('wishlist', utils.MODE_ADVANCED).keys()),
-                              ['a11y', 'l10n', 'd-i', 'ipv6', 'patch', 'lfs', 'upstream', 'security', 'newcomer', 'ftbfs'])
+        self.assertCountEqual(list(debbugs.get_tags('critical', utils.MODE.ADVANCED).keys()),
+                              ['a11y', 'l10n', 'd-i', 'ipv6', 'patch', 'lfs', 'upstream', 'security', 'newcomer', 'ftbfs', 'arch'])
+        self.assertCountEqual(list(debbugs.get_tags('grave', utils.MODE.ADVANCED).keys()),
+                              ['a11y', 'l10n', 'd-i', 'ipv6', 'patch', 'lfs', 'upstream', 'security', 'newcomer', 'ftbfs', 'arch'])
+        self.assertCountEqual(list(debbugs.get_tags('serious', utils.MODE.ADVANCED).keys()),
+                              ['a11y', 'l10n', 'd-i', 'ipv6', 'patch', 'lfs', 'upstream', 'security', 'newcomer', 'ftbfs', 'arch'])
+        self.assertCountEqual(list(debbugs.get_tags('important', utils.MODE.ADVANCED).keys()),
+                              ['a11y', 'l10n', 'd-i', 'ipv6', 'patch', 'lfs', 'upstream', 'security', 'newcomer', 'ftbfs', 'arch'])
+        self.assertCountEqual(list(debbugs.get_tags('does-not-build', utils.MODE.ADVANCED).keys()),
+                              ['a11y', 'l10n', 'd-i', 'ipv6', 'patch', 'lfs', 'upstream', 'security', 'newcomer', 'ftbfs', 'arch'])
+        self.assertCountEqual(list(debbugs.get_tags('normal', utils.MODE.ADVANCED).keys()),
+                              ['a11y', 'l10n', 'd-i', 'ipv6', 'patch', 'lfs', 'upstream', 'security', 'newcomer', 'ftbfs', 'arch'])
+        self.assertCountEqual(list(debbugs.get_tags('non-critical', utils.MODE.ADVANCED).keys()),
+                              ['a11y', 'l10n', 'd-i', 'ipv6', 'patch', 'lfs', 'upstream', 'security', 'newcomer', 'ftbfs', 'arch'])
+        self.assertCountEqual(list(debbugs.get_tags('minor', utils.MODE.ADVANCED).keys()),
+                              ['a11y', 'l10n', 'd-i', 'ipv6', 'patch', 'lfs', 'upstream', 'security', 'newcomer', 'ftbfs', 'arch'])
+        self.assertCountEqual(list(debbugs.get_tags('wishlist', utils.MODE.ADVANCED).keys()),
+                              ['a11y', 'l10n', 'd-i', 'ipv6', 'patch', 'lfs', 'upstream', 'security', 'newcomer', 'ftbfs', 'arch'])
 
-        self.assertCountEqual(list(debbugs.get_tags('critical', utils.MODE_EXPERT).keys()),
-                              ['a11y', 'l10n', 'd-i', 'ipv6', 'patch', 'lfs', 'upstream', 'security', 'newcomer', 'ftbfs'])
-        self.assertCountEqual(list(debbugs.get_tags('grave', utils.MODE_EXPERT).keys()),
-                              ['a11y', 'l10n', 'd-i', 'ipv6', 'patch', 'lfs', 'upstream', 'security', 'newcomer', 'ftbfs'])
-        self.assertCountEqual(list(debbugs.get_tags('serious', utils.MODE_EXPERT).keys()),
-                              ['a11y', 'l10n', 'd-i', 'ipv6', 'patch', 'lfs', 'upstream', 'security', 'newcomer', 'ftbfs'])
-        self.assertCountEqual(list(debbugs.get_tags('important', utils.MODE_EXPERT).keys()),
-                              ['a11y', 'l10n', 'd-i', 'ipv6', 'patch', 'lfs', 'upstream', 'security', 'newcomer', 'ftbfs'])
-        self.assertCountEqual(list(debbugs.get_tags('does-not-build', utils.MODE_EXPERT).keys()),
-                              ['a11y', 'l10n', 'd-i', 'ipv6', 'patch', 'lfs', 'upstream', 'security', 'newcomer', 'ftbfs'])
-        self.assertCountEqual(list(debbugs.get_tags('normal', utils.MODE_EXPERT).keys()),
-                              ['a11y', 'l10n', 'd-i', 'ipv6', 'patch', 'lfs', 'upstream', 'security', 'newcomer', 'ftbfs'])
-        self.assertCountEqual(list(debbugs.get_tags('non-critical', utils.MODE_EXPERT).keys()),
-                              ['a11y', 'l10n', 'd-i', 'ipv6', 'patch', 'lfs', 'upstream', 'security', 'newcomer', 'ftbfs'])
-        self.assertCountEqual(list(debbugs.get_tags('minor', utils.MODE_EXPERT).keys()),
-                              ['a11y', 'l10n', 'd-i', 'ipv6', 'patch', 'lfs', 'upstream', 'security', 'newcomer', 'ftbfs'])
-        self.assertCountEqual(list(debbugs.get_tags('wishlist', utils.MODE_EXPERT).keys()),
-                              ['a11y', 'l10n', 'd-i', 'ipv6', 'patch', 'lfs', 'upstream', 'security', 'newcomer', 'ftbfs'])
+        self.assertCountEqual(list(debbugs.get_tags('critical', utils.MODE.EXPERT).keys()),
+                              ['a11y', 'l10n', 'd-i', 'ipv6', 'patch', 'lfs', 'upstream', 'security', 'newcomer', 'ftbfs', 'arch'])
+        self.assertCountEqual(list(debbugs.get_tags('grave', utils.MODE.EXPERT).keys()),
+                              ['a11y', 'l10n', 'd-i', 'ipv6', 'patch', 'lfs', 'upstream', 'security', 'newcomer', 'ftbfs', 'arch'])
+        self.assertCountEqual(list(debbugs.get_tags('serious', utils.MODE.EXPERT).keys()),
+                              ['a11y', 'l10n', 'd-i', 'ipv6', 'patch', 'lfs', 'upstream', 'security', 'newcomer', 'ftbfs', 'arch'])
+        self.assertCountEqual(list(debbugs.get_tags('important', utils.MODE.EXPERT).keys()),
+                              ['a11y', 'l10n', 'd-i', 'ipv6', 'patch', 'lfs', 'upstream', 'security', 'newcomer', 'ftbfs', 'arch'])
+        self.assertCountEqual(list(debbugs.get_tags('does-not-build', utils.MODE.EXPERT).keys()),
+                              ['a11y', 'l10n', 'd-i', 'ipv6', 'patch', 'lfs', 'upstream', 'security', 'newcomer', 'ftbfs', 'arch'])
+        self.assertCountEqual(list(debbugs.get_tags('normal', utils.MODE.EXPERT).keys()),
+                              ['a11y', 'l10n', 'd-i', 'ipv6', 'patch', 'lfs', 'upstream', 'security', 'newcomer', 'ftbfs', 'arch'])
+        self.assertCountEqual(list(debbugs.get_tags('non-critical', utils.MODE.EXPERT).keys()),
+                              ['a11y', 'l10n', 'd-i', 'ipv6', 'patch', 'lfs', 'upstream', 'security', 'newcomer', 'ftbfs', 'arch'])
+        self.assertCountEqual(list(debbugs.get_tags('minor', utils.MODE.EXPERT).keys()),
+                              ['a11y', 'l10n', 'd-i', 'ipv6', 'patch', 'lfs', 'upstream', 'security', 'newcomer', 'ftbfs', 'arch'])
+        self.assertCountEqual(list(debbugs.get_tags('wishlist', utils.MODE.EXPERT).keys()),
+                              ['a11y', 'l10n', 'd-i', 'ipv6', 'patch', 'lfs', 'upstream', 'security', 'newcomer', 'ftbfs', 'arch'])
 
 
 class TestInfofunc(unittest.TestCase):
